"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.flagEnabled = flagEnabled;
exports.issueFlagNotices = issueFlagNotices;
exports.default = void 0;

var _chalk = _interopRequireDefault(require("chalk"));

var _log = _interopRequireDefault(require("./util/log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const featureFlags = {
  future: [],
  experimental: ['optimizeUniversalDefaults']
};

function flagEnabled(config, flag) {
  if (featureFlags.future.includes(flag)) {
    var _config$future$flag, _config$future;

    return config.future === 'all' || ((_config$future$flag = config === null || config === void 0 ? void 0 : (_config$future = config.future) === null || _config$future === void 0 ? void 0 : _config$future[flag]) !== null && _config$future$flag !== void 0 ? _config$future$flag : false);
  }

  if (featureFlags.experimental.includes(flag)) {
    var _config$experimental$, _config$experimental;

    return config.experimental === 'all' || ((_config$experimental$ = config === null || config === void 0 ? void 0 : (_config$experimental = config.experimental) === null || _config$experimental === void 0 ? void 0 : _config$experimental[flag]) !== null && _config$experimental$ !== void 0 ? _config$experimental$ : false);
  }

  return false;
}

function experimentalFlagsEnabled(config) {
  var _config$experimental2;

  if (config.experimental === 'all') {
    return featureFlags.experimental;
  }

  return Object.keys((_config$experimental2 = config === null || config === void 0 ? void 0 : config.experimental) !== null && _config$experimental2 !== void 0 ? _config$experimental2 : {}).filter(flag => featureFlags.experimental.includes(flag) && config.experimental[flag]);
}

function issueFlagNotices(config) {
  if (process.env.JEST_WORKER_ID !== undefined) {
    return;
  }

  if (experimentalFlagsEnabled(config).length > 0) {
    const changes = experimentalFlagsEnabled(config).map(s => _chalk.default.yellow(s)).join(', ');

    _log.default.warn([`You have enabled experimental features: ${changes}`, 'Experimental features are not covered by semver, may introduce breaking changes, and can change at any time.']);
  }
}

var _default = featureFlags;
exports.default = _default;